import { AxiosRequestConfig } from 'axios';
import { LaunchOptions } from 'puppeteer';

type EngineTypes = "html" | "spa" | "json" | "xml";
declare enum EngineType {
    Html = "html",
    Spa = "spa",
    Json = "json",
    Xml = "xml"
}
type TScrapedData = Record<string, any>;
type TScrapedDataPromise = Promise<TScrapedData>;
interface ISelectorWithAttribute {
    selector: string;
    attribute?: string;
}
type TSelectors = Record<string, ISelectorWithAttribute>;
interface IScrapeHtmlOptions {
    selectors: TSelectors;
    request?: AxiosRequestConfig;
}
interface IScrapeSpaOptions {
    selectors: TSelectors;
    request?: LaunchOptions;
}
interface IScrapeJsonOptions {
    selectors: TSelectors;
    request?: AxiosRequestConfig;
}
interface IScrapeXmlOptions {
    selectors: TSelectors;
    request?: AxiosRequestConfig;
}
interface IScrapeOptions {
    url: string;
    engine: EngineType | EngineTypes;
    options: IScrapeHtmlOptions & IScrapeSpaOptions & IScrapeJsonOptions & IScrapeXmlOptions;
}

declare const scrape: ({ url, engine, options, }: IScrapeOptions) => TScrapedDataPromise;

declare const scrapeHtml: (url: string, { selectors, request }: IScrapeHtmlOptions) => TScrapedDataPromise;

declare const scrapeSpa: (url: string, { selectors, request }: IScrapeSpaOptions) => TScrapedDataPromise;

declare const scrapeXml: (url: string, { selectors, request }: IScrapeXmlOptions) => TScrapedDataPromise;

declare const scrapeJson: (url: string, { selectors, request }: IScrapeXmlOptions) => TScrapedDataPromise;

export { EngineType, EngineTypes, IScrapeHtmlOptions, IScrapeJsonOptions, IScrapeOptions, IScrapeSpaOptions, IScrapeXmlOptions, ISelectorWithAttribute, TScrapedData, TScrapedDataPromise, TSelectors, scrape, scrapeHtml, scrapeJson, scrapeSpa, scrapeXml };
